Authenticated trading-account endpoints (/api/v5/account/*).
Structs
- Account
- Accessor for the authenticated account endpoints.
- Account
Balance - The trading-account balance summary.
- Account
Bill - Account bill row.
- Account
Config - Account configuration.
- Account
Instrument - Account-level instrument configuration.
- Account
Instruments Request - Query parameters for account instruments.
- Account
Position Tier - Account position-tier row.
- Account
Position Tiers Request - Query parameters for account position tiers.
- Activate
Option Result - Result of activating option trading.
- Adjust
Leverage Info - Estimated impact and limits for a leverage adjustment.
- Adjust
Leverage Info Request - Query parameters for estimating leverage adjustment effects.
- Adjust
Margin Request - Request body for adjusting position margin.
- Adjust
Margin Result - Result of adding or reducing margin on a position.
- Apply
Bills History Archive Result - Result returned after applying for historical account-bills archive generation.
- Balance
Detail - Balance details for a single currency.
- Balance
Request - Request for
get_balance,get_interest_rate,get_max_withdrawal, andget_greeks. - Bill
Subtype Detail - Account bill subtype details.
- Bill
Subtype Mapping - Mapping for an account bill type and its subtypes.
- Bill
Subtypes Request - Query parameters for account bill type/subtype mapping.
- Bills
Archive Request - Query parameters for archived account bills.
- Bills
History Archive File - Historical account-bills archive download-link information.
- Bills
History Archive Request - Parameters for historical account-bills archive generation and download-link lookup.
- Bills
Request - Query parameters for account bills.
- Borrow
Repay History - Borrow/repay history row.
- Borrow
Repay History Request - Query parameters for borrow/repay history.
- Borrow
Repay Request - Request body for borrow/repay.
- Borrow
Repay Result - Result of a borrow/repay request.
- FeeGroup
- Fee-rate group row nested in
FeeRate. - FeeRate
- Trade fee-rate information.
- FeeRates
Request - Query parameters for trade fee rates.
- Greek
- Account greeks row.
- Interest
Accrued - Interest accrued by account borrowing.
- Interest
Accrued Request - Query parameters for interest-accrued records.
- Interest
Limit - Borrowing interest and limit information, as returned by
GET /api/v5/account/interest-limits. - Interest
Limits Request - Query parameters for interest limits.
- Interest
Rate - Account borrowing interest rate.
- Leverage
Info - Leverage information.
- Leverage
Request - Query parameters for retrieving leverage.
- Loan
Record - Per-currency loan record nested in
InterestLimit. - MaxAvailable
Size - Maximum available size information.
- MaxAvailable
Size Request - Query parameters for maximum available size.
- MaxLoan
- Maximum loan amount available for an instrument or currency.
- MaxLoan
Request - Query parameters for maximum loan.
- MaxOrder
Size - Maximum order size information.
- MaxOrder
Size Request - Query parameters for maximum order size.
- MaxWithdrawal
- Maximum withdrawal amount for a currency.
- Position
- An open position.
- Position
Builder Asset - Asset info returned by position builder.
- Position
Builder Mr1Scenarios - MR1 scenario analysis for a risk unit.
- Position
Builder Request - Request body for position builder.
- Position
Builder Result - Position-builder result, as returned by
POST /api/v5/account/position-builder. - Position
Builder Risk Unit - Risk unit info returned by position builder.
- Position
History - Historical position row.
- Position
Risk - Account position-risk snapshot.
- Position
Risk Request - Request for
get_position_risk. - Positions
History Request - Query parameters for position history.
- Positions
Request - Request for
get_positions. - Risk
State - Account risk state, as returned by
GET /api/v5/account/risk-state. - SetAccount
Level Request - Request for
set_account_level. - SetAccount
Level Result - Result of updating account level.
- SetAuto
Earn Request - Request body for
POST /api/v5/account/set-auto-earn. - SetAuto
Earn Result - Auto-earn setting result.
- SetAuto
Loan Request - Request for
set_auto_loan. - SetAuto
Loan Result - Result of updating auto loan.
- SetAuto
Repay Request - Request body for
POST /api/v5/account/set-auto-repay. - SetAuto
Repay Result - Auto-repay setting result.
- SetCollateral
Assets Request - Request for
set_collateral_assets. - SetCollateral
Assets Result - Result of updating collateral assets.
- SetGreeks
Request - Request for
set_greeks. - SetGreeks
Result - Result of updating the greeks display type.
- SetIsolated
Mode Request - Request for
set_isolated_mode. - SetIsolated
Mode Result - Result of updating isolated margin mode.
- SetLeverage
Request - Request body for setting leverage.
- SetPosition
Mode Request - Request for
set_position_mode. - SetPosition
Mode Result - Result of setting position mode.
- SetRisk
Offset Amount Request - Request body for setting the spot risk offset amount.
- SetRisk
Offset Amount Result - Result of setting the spot risk offset amount.
- Simulated
Asset - A simulated asset used by position-builder requests.
- Simulated
Margin - Simulated margin calculation result.
- Simulated
Margin Detail - Per-instrument detail in a simulated margin response.
- Simulated
Margin Request - Request body for simulated margin calculation.
- Simulated
Position - A simulated position used by position-builder and simulated-margin requests.
- Spot
Borrow Repay History - Spot borrow/repay history row.
- Spot
Borrow Repay History Request - Query parameters for
GET /api/v5/account/spot-borrow-repay-history. - Spot
Borrow Repay Result - Spot borrow/repay mutation result.
- Spot
Manual Borrow Repay Request - Request body for
POST /api/v5/account/spot-manual-borrow-repay.
Enums
- Bills
History Archive File State - Download-link state for historical account-bills archive files.
- Bills
History Archive Quarter - Quarter selector for historical account-bills archive generation.
- Bills
History Archive Status - Status returned after applying for a historical bills archive.
Type Aliases
- Apply
Bills History Archive Request - Request body for applying historical account-bills archive generation.