#[non_exhaustive]pub struct AdjustLeverageInfo {
pub est_avail_quote_trans: NumberString,
pub est_avail_trans: NumberString,
pub est_liq_px: NumberString,
pub est_max_amt: NumberString,
pub est_mgn: NumberString,
pub est_quote_mgn: NumberString,
pub est_quote_max_amt: NumberString,
pub exist_ord: bool,
pub max_lever: NumberString,
pub min_lever: NumberString,
}Expand description
Estimated impact and limits for a leverage adjustment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.est_avail_quote_trans: NumberStringEstimated margin in quote currency that can be transferred out.
est_avail_trans: NumberStringEstimated margin that can be transferred out.
est_liq_px: NumberStringEstimated liquidation price.
est_max_amt: NumberStringEstimated maximum amount / contract quantity.
est_mgn: NumberStringEstimated margin needed by the position.
est_quote_mgn: NumberStringEstimated margin in quote currency needed by the position.
est_quote_max_amt: NumberStringEstimated maximum quote-currency loan amount for margin.
exist_ord: boolWhether pending orders exist.
max_lever: NumberStringMaximum leverage.
min_lever: NumberStringMinimum leverage.