#[non_exhaustive]pub struct ConvertCurrency {
pub ccy: String,
pub min: NumberString,
pub max: NumberString,
}Expand description
A currency supported by OKX Convert.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ccy: StringCurrency code, e.g. BTC.
min: NumberStringDeprecated minimum amount to convert.
OKX currently returns an empty string for this field.
max: NumberStringDeprecated maximum amount to convert.
OKX currently returns an empty string for this field.