#[non_exhaustive]pub struct ConvertCurrencyPair {
pub inst_id: String,
pub base_ccy: String,
pub base_ccy_max: NumberString,
pub base_ccy_min: NumberString,
pub quote_ccy: String,
pub quote_ccy_max: NumberString,
pub quote_ccy_min: NumberString,
}Expand description
Limits and metadata for a currency pair supported by OKX Convert.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inst_id: StringCurrency pair, e.g. BTC-USDT.
base_ccy: StringBase currency, e.g. BTC in BTC-USDT.
base_ccy_max: NumberStringMaximum amount of base currency that can be converted.
base_ccy_min: NumberStringMinimum amount of base currency that can be converted.
quote_ccy: StringQuote currency, e.g. USDT in BTC-USDT.
quote_ccy_max: NumberStringMaximum amount of quote currency that can be converted.
quote_ccy_min: NumberStringMinimum amount of quote currency that can be converted.