pub struct AlgoOrderListRequest<'a> { /* private fields */ }Expand description
Query parameters shared by pending and historical algo orders.
Implementations
Sourceimpl<'a> AlgoOrderListRequest<'a>
impl<'a> AlgoOrderListRequest<'a>
Sourcepub fn new(ord_type: impl Into<Cow<'a, str>>) -> Self
pub fn new(ord_type: impl Into<Cow<'a, str>>) -> Self
Create a query for one documented algo order type.
Sourcepub fn after(self, value: impl Into<Cow<'a, str>>) -> Self
pub fn after(self, value: impl Into<Cow<'a, str>>) -> Self
Return records before this algo-ID cursor.