FillHistory

Struct FillHistory 

#[non_exhaustive]
pub struct FillHistory {
Show 24 fields pub inst_type: String, pub inst_id: String, pub trade_id: String, pub ord_id: String, pub cl_ord_id: String, pub bill_id: String, pub tag: String, pub fill_px: NumberString, pub fill_sz: NumberString, pub fill_idx_px: NumberString, pub fill_pnl: NumberString, pub fill_px_vol: NumberString, pub fill_px_usd: NumberString, pub fill_mark_vol: NumberString, pub fill_fwd_px: NumberString, pub fill_mark_px: NumberString, pub side: OrderSide, pub pos_side: String, pub exec_type: String, pub fee_ccy: String, pub fee: NumberString, pub fee_rate: NumberString, pub fill_time: NumberString, pub ts: NumberString,
}
Historical fill returned by GET /api/v5/trade/fills-history.

OKX documents this response separately from recent fills and does not return ordType here, so this type intentionally does not reuse Fill.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
inst_type: String

Instrument type.

inst_id: String

Instrument ID.

trade_id: String

Trade ID.

ord_id: String

OKX order ID.

cl_ord_id: String

Client order ID.

bill_id: String

Bill ID.

tag: String

Order tag.

fill_px: NumberString

Fill price.

fill_sz: NumberString

Fill size.

fill_idx_px: NumberString

Index price at fill time.

fill_pnl: NumberString

Fill profit and loss.

fill_px_vol: NumberString

Implied volatility at fill price.

fill_px_usd: NumberString

Fill price in USD.

fill_mark_vol: NumberString

Mark volatility at fill time.

fill_fwd_px: NumberString

Forward price at fill time.

fill_mark_px: NumberString

Mark price at fill time.

side: OrderSide

Fill side.

pos_side: String

Position side.

exec_type: String

Liquidity role, e.g. T or M.

fee_ccy: String

Fee currency.

fee: NumberString

Fee amount.

fee_rate: NumberString

Fee rate.

fill_time: NumberString

Fill timestamp (Unix milliseconds).

ts: NumberString

Trade creation timestamp (Unix milliseconds).