RequestValidationError

Enum RequestValidationError 

#[non_exhaustive]
pub enum RequestValidationError { EmptyField { field: &'static str, }, TooLong { field: &'static str, max: usize, }, LengthOutOfRange { field: &'static str, min: usize, max: usize, }, InvalidFormat { field: &'static str, expected: &'static str, }, OutOfRange { field: &'static str, min: u64, max: u64, }, DecimalOutOfRange { field: &'static str, min: &'static str, max: &'static str, }, RequiredWhen { field: &'static str, condition: &'static str, }, NotApplicable { field: &'static str, condition: &'static str, }, AtLeastOneRequired { fields: &'static str, }, MutuallyExclusive { fields: &'static str, }, }
A validation failure detected before an HTTP request is sent.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyField

A required string field was empty.

Fields

field: &'static str

OKX wire-field name.



TooLong

A string field exceeded the endpoint’s documented maximum length.

Fields

field: &'static str

OKX wire-field name.

max: usize

Maximum allowed character count.



LengthOutOfRange

A string field’s length was outside the documented range.

Fields

field: &'static str

OKX wire-field name.

min: usize

Inclusive minimum character count.

max: usize

Inclusive maximum character count.



InvalidFormat

A field did not match the endpoint’s required textual format.

Fields

field: &'static str

OKX wire-field name.

expected: &'static str

Human-readable description of the expected format.



OutOfRange

A numeric request value was outside the endpoint’s documented range.

Fields

field: &'static str

OKX wire-field name.

min: u64

Inclusive lower bound.

max: u64

Inclusive upper bound.



DecimalOutOfRange

A decimal-string request value was outside the documented range.

Fields

field: &'static str

OKX wire-field name.

min: &'static str

Inclusive lower bound as documented by OKX.

max: &'static str

Inclusive upper bound as documented by OKX.



RequiredWhen

A field is required under a particular condition.

Fields

field: &'static str

OKX wire-field name.

condition: &'static str

Human-readable description of the condition.



NotApplicable

A field is not applicable under a particular condition.

Fields

field: &'static str

OKX wire-field name.

condition: &'static str

Human-readable description of the condition.



AtLeastOneRequired

None of a set of conditionally required fields was provided.

Fields

fields: &'static str

Comma-separated OKX wire-field names.



MutuallyExclusive

More than one mutually exclusive field was provided.

Fields

fields: &'static str

Comma-separated OKX wire-field names.