WsError

Enum WsError 

#[non_exhaustive]
pub enum WsError { Transport { source: TransportError, }, Decode { context: String, source: Error, }, MissingArg { raw: String, }, Encode { source: Error, }, Configuration(String), }
Errors from the WebSocket layer.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Transport

A WebSocket transport error (connection, TLS, I/O, …).

Fields

source: TransportError

Finding the position of the error



Decode

A WebSocket event or push payload could not be decoded.

Fields

context: String

Human-readable context: channel name, event type, or a snippet of the raw payload.

source: Error

The underlying deserialization error.



MissingArg

A push event was missing the required arg field.

Fields

raw: String

The raw JSON text of the offending event (truncated if large).



Encode

An outgoing WebSocket request could not be serialized.

Fields

source: Error

The underlying serialization error.



Configuration(String)

The WebSocket client was used in an invalid way (wrong channel group, missing credentials, …).