#[non_exhaustive]pub struct Trade {
pub inst_id: String,
pub trade_id: String,
pub extra: ExtraFields,
}Expand description
A trade associated with a balance or position update.
The trades array identifies fills related to the pushed balance or
position change.
OKX docs: https://www.okx.com/docs-v5/en/#trading-account-websocket-balance-and-position-channel
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inst_id: StringInstrument ID, for example BTC-USDT or BTC-USDT-SWAP.
trade_id: StringTrade ID assigned by OKX.
This value should be treated as an opaque identifier.
extra: ExtraFieldsAdditional fields added by OKX that are not yet represented explicitly.