#[non_exhaustive]pub struct BookLevel {
pub price: NumberString,
pub size: NumberString,
pub liquidated_order_count: NumberString,
pub order_count: NumberString,
}Expand description
A single four-value WebSocket order-book level.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.price: NumberStringThe limit price of this order book level.
size: NumberStringThe total depth or size available at this price level (in coins or contracts).
liquidated_order_count: NumberStringThe number of liquidation orders currently resting at this price level.
order_count: NumberStringThe total number of individual orders making up the total size at this level.