OrderUpdate

Struct OrderUpdate 

#[non_exhaustive]
pub struct OrderUpdate {
Show 69 fields pub inst_type: String, pub inst_id: String, pub tgt_ccy: String, pub ccy: String, pub ord_id: String, pub cl_ord_id: String, pub tag: String, pub px: NumberString, pub sz: NumberString, pub notional_usd: NumberString, pub ord_type: String, pub side: String, pub pos_side: String, pub td_mode: String, pub acc_fill_sz: NumberString, pub fill_px: NumberString, pub trade_id: String, pub fill_sz: NumberString, pub fill_time: NumberString, pub fill_pnl: NumberString, pub fill_fee: NumberString, pub fill_fee_ccy: String, pub fill_notional_usd: NumberString, pub fill_px_vol: NumberString, pub fill_px_usd: NumberString, pub fill_mark_vol: NumberString, pub fill_fwd_px: NumberString, pub fill_mark_px: NumberString, pub fill_idx_px: NumberString, pub exec_type: String, pub avg_px: NumberString, pub state: String, pub lever: NumberString, pub attach_algo_cl_ord_id: String, pub tp_trigger_px: NumberString, pub tp_trigger_px_type: String, pub tp_ord_px: NumberString, pub sl_trigger_px: NumberString, pub sl_trigger_px_type: String, pub sl_ord_px: NumberString, pub fee_ccy: String, pub fee: NumberString, pub rebate_ccy: String, pub rebate: NumberString, pub pnl: NumberString, pub source: String, pub category: String, pub reduce_only: String, pub is_tp_limit: String, pub cancel_source: String, pub algo_cl_ord_id: String, pub algo_id: String, pub amend_source: String, pub amend_result: String, pub req_id: String, pub code: String, pub msg: String, pub px_type: String, pub px_usd: NumberString, pub px_vol: NumberString, pub linked_algo_ord: Value, pub attach_algo_ords: Vec<Value>, pub stp_mode: String, pub trade_quote_ccy: String, pub last_px: NumberString, pub outcome: String, pub c_time: NumberString, pub u_time: NumberString, pub extra: ExtraFields,
}
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
inst_type: String

Instrument type, e.g., SPOT, MARGIN, SWAP, FUTURES, OPTION.

inst_id: String

Instrument ID, e.g., BTC-USDT.

tgt_ccy: String

Target currency for quantity (spot currency-trade only).

base_ccy means the order size is in base currency; quote_ccy means the order size is in quote currency.

ccy: String

Margin currency (for cross-margin orders; empty otherwise).

ord_id: String

OKX-assigned order ID.

cl_ord_id: String

Client-supplied order ID, if any.

tag: String

Order tag.

px: NumberString

Order price; empty for market orders.

sz: NumberString

Order size.

notional_usd: NumberString

Estimated notional value of the order in USD.

ord_type: String

Order type.

Documented values: market, limit, post_only, fok, ioc, optimal_limit_ioc, mmp, mmp_and_post_only, op_fok, elp.

side: String

Order side: buy or sell.

pos_side: String

Position side: long, short, or net.

td_mode: String

Trade mode: cross, isolated, or cash.

acc_fill_sz: NumberString

Accumulated filled size.

fill_px: NumberString

Fill price of the most recent fill in this push.

trade_id: String

Trade ID of the most recent fill.

fill_sz: NumberString

Fill size of the most recent fill.

fill_time: NumberString

Fill timestamp of the most recent fill (Unix milliseconds).

fill_pnl: NumberString

Fill PnL of the most recent fill.

fill_fee: NumberString

Fee charged for the most recent fill.

fill_fee_ccy: String

Fee currency for the most recent fill.

fill_notional_usd: NumberString

Filled notional value in USD for the most recent fill.

fill_px_vol: NumberString

Implied volatility at fill (options only).

fill_px_usd: NumberString

USD-denominated option price at fill (options only).

fill_mark_vol: NumberString

Mark implied volatility at fill (options only).

fill_fwd_px: NumberString

Forward price at fill (options only).

fill_mark_px: NumberString

Mark price at fill (FUTURES, SWAP, OPTION).

fill_idx_px: NumberString

Index price at fill.

exec_type: String

Liquidity role for the most recent fill: T (taker) or M (maker).

avg_px: NumberString

Average fill price.

state: String

Order state.

Documented values: live, partially_filled, filled, canceled, mmp_canceled.

lever: NumberString

Leverage.

attach_algo_cl_ord_id: String

Client-supplied attached algo order ID.

tp_trigger_px: NumberString

Take-profit trigger price.

tp_trigger_px_type: String

Take-profit trigger price type: last, index, or mark.

tp_ord_px: NumberString

Take-profit order price; -1 means market order.

sl_trigger_px: NumberString

Stop-loss trigger price.

sl_trigger_px_type: String

Stop-loss trigger price type: last, index, or mark.

sl_ord_px: NumberString

Stop-loss order price; -1 means market order.

fee_ccy: String

Fee currency.

fee: NumberString

Fee amount; negative means deducted, positive means maker rebate.

rebate_ccy: String

Rebate currency.

rebate: NumberString

Rebate amount (maker rebate).

pnl: NumberString

Profit and loss for closing orders.

source: String

Order source (internal OKX field).

category: String

Order category.

Documented values: normal, twap, adl, full_liquidation, partial_liquidation, delivery, ddh, auto_conversion.

reduce_only: String

Whether this is a reduce-only order: "true" or "false".

is_tp_limit: String

Whether this is a TP limit order: "true" or "false".

cancel_source: String

Source that triggered the cancellation.

algo_cl_ord_id: String

Client-supplied algo order ID that triggered this order.

algo_id: String

OKX-assigned algo order ID that triggered this order.

amend_source: String

Source of the last amendment.

amend_result: String

Result of the last amendment.

-1: failure, 0: success, 1: auto-canceled, 2: auto-amended (options only).

req_id: String

Client-supplied request ID, echoed from the operation that caused this push.

code: String

Error code; "0" on success.

msg: String

Error message; empty on success.

px_type: String

Price type for options: px (price), pxVol (IV), or pxUsd (USD price).

px_usd: NumberString

USD-denominated option order price.

px_vol: NumberString

Implied-volatility option order price.

linked_algo_ord: Value

Linked algo order details (JSON object; empty when not linked).

attach_algo_ords: Vec<Value>

Attached algo orders (TP/SL orders attached to this order).

stp_mode: String

Self-trade prevention mode: cancel_maker, cancel_taker, or cancel_both.

trade_quote_ccy: String

Quote currency used for the trade (event contracts only).

last_px: NumberString

Last price at the time of the push.

outcome: String

Settlement outcome (event contracts only): yes or no.

c_time: NumberString

Order creation time (Unix milliseconds).

u_time: NumberString

Last update time (Unix milliseconds).

extra: ExtraFields

Unrecognized fields retained for forward compatibility.