#[non_exhaustive]pub struct BlockTicker {Show 14 fields
pub inst_type: String,
pub inst_id: String,
pub last: NumberString,
pub last_sz: NumberString,
pub ask_px: NumberString,
pub ask_sz: NumberString,
pub bid_px: NumberString,
pub bid_sz: NumberString,
pub open24h: NumberString,
pub high24h: NumberString,
pub low24h: NumberString,
pub vol24h: NumberString,
pub vol_ccy24h: NumberString,
pub ts: NumberString,
}Expand description
A block-trading ticker snapshot.
OKX block ticker rows are sparser than regular ticker rows, so fields that
are required by Ticker are optional/defaulted here.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inst_type: StringInstrument type, when present.
inst_id: StringInstrument ID, e.g. BTC-USDT-SWAP.
last: NumberStringLast traded price, when present.
last_sz: NumberStringLast traded size, when present.
ask_px: NumberStringBest ask price, when present.
ask_sz: NumberStringBest ask size, when present.
bid_px: NumberStringBest bid price, when present.
bid_sz: NumberStringBest bid size, when present.
open24h: NumberStringOpen price over the last 24 hours, when present.
high24h: NumberStringHighest price over the last 24 hours, when present.
low24h: NumberStringLowest price over the last 24 hours, when present.
vol24h: NumberStringTrading volume over the last 24 hours, when present.
vol_ccy24h: NumberStringTrading volume in currency units over the last 24 hours, when present.
ts: NumberStringTicker timestamp (Unix milliseconds), when present.