pub struct AlgoOrderListRequest { /* private fields */ }Expand description
Query parameters shared by pending and historical algo orders.
Implementations
Sourceimpl AlgoOrderListRequest
impl AlgoOrderListRequest
Sourcepub fn new(ord_type: impl Into<String>) -> Self
pub fn new(ord_type: impl Into<String>) -> Self
Create a query for one documented algo order type.
Sourcepub fn after(self, value: impl Into<String>) -> Self
pub fn after(self, value: impl Into<String>) -> Self
Return records before this algo-ID cursor.