#[non_exhaustive]pub enum RequestValidationError {
EmptyField {
field: &'static str,
},
TooLong {
field: &'static str,
max: usize,
},
LengthOutOfRange {
field: &'static str,
min: usize,
max: usize,
},
InvalidFormat {
field: &'static str,
expected: &'static str,
},
OutOfRange {
field: &'static str,
min: u64,
max: u64,
},
DecimalOutOfRange {
field: &'static str,
min: &'static str,
max: &'static str,
},
RequiredWhen {
field: &'static str,
condition: &'static str,
},
NotApplicable {
field: &'static str,
condition: &'static str,
},
AtLeastOneRequired {
fields: &'static str,
},
MutuallyExclusive {
fields: &'static str,
},
}Expand description
A validation failure detected before an HTTP request is sent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyField
A required string field was empty.
TooLong
A string field exceeded the endpoint’s documented maximum length.
LengthOutOfRange
A string field’s length was outside the documented range.
Fields
InvalidFormat
A field did not match the endpoint’s required textual format.
Fields
OutOfRange
A numeric request value was outside the endpoint’s documented range.
Fields
DecimalOutOfRange
A decimal-string request value was outside the documented range.
Fields
RequiredWhen
A field is required under a particular condition.
Fields
NotApplicable
A field is not applicable under a particular condition.
Fields
AtLeastOneRequired
None of a set of conditionally required fields was provided.
MutuallyExclusive
More than one mutually exclusive field was provided.