#[non_exhaustive]pub enum WsError {
Transport {
source: TransportError,
},
Decode {
context: String,
source: Error,
},
MissingArg {
raw: String,
},
Encode {
source: Error,
},
Configuration(String),
}Expand description
Errors from the WebSocket layer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Transport
A WebSocket transport error (connection, TLS, I/O, …).
Fields

source: TransportErrorFinding the position of the error
Decode
A WebSocket event or push payload could not be decoded.
Fields
MissingArg
A push event was missing the required arg field.
Encode
An outgoing WebSocket request could not be serialized.
Configuration(String)
The WebSocket client was used in an invalid way (wrong channel group, missing credentials, …).